AnalyzerIssue class

Constructors

AnalyzerIssue({required String file, required int line, required int column, required String severity, required String message})

Properties

column int
final
file String
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
no setter
isInfo bool
no setter
isWarning bool
no setter
line int
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited