AnalyzerValidator class

Runs dart/flutter analyze and provides auto-fix capabilities

Constructors

AnalyzerValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

analyze(String directory, {bool useFlutter = true}) Future<AnalysisResult>
Run dart analyze on a directory and return analysis results
autoFixCommonIssues(String content) String
Auto-fix common issues after refactoring
parseIssues(String analyzerOutput) List<AnalyzerIssue>
Parse analyzer output to extract common fixable issues
runDartFix(String directory) Future<bool>
Run dart fix --apply for automated fixes