CacheManager class

Constructors

CacheManager(String rootPath)

Properties

files Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
projectRoot Directory
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFileEntry(String filePath) Map<String, dynamic>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFileEntry(String filePath) → void
save() → void
toString() String
A string representation of this object.
inherited
updateFileEntry(String filePath, String hash, List<String> strings) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

computeFileHash(File f) String
computeHashForString(String input) String