ContextInjector class

Injects BuildContext parameter into Widget-returning functions that need it

Constructors

ContextInjector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fixFunctionCalls(String content, List<String> functionNames) String
Fix function calls to pass context parameter
injectContextParameter(String content) String
Analyze and fix functions that return Widgets but lack BuildContext parameter