LocalizationRefactorer class

Constructors

LocalizationRefactorer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addLocalizationImport(String content, String packageName) String
Add AppLocalizations import if needed
batchRefactor({required String content, required Map<String, String> replacements, bool useAppLocalizations = true, bool preserveConst = true}) Map<String, dynamic>
Refactors code to use localized strings with AppLocalizations