PreferencesManager class

Class to manage user preferences for the CLI tool

Constructors

PreferencesManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

loadPreferences() Map<String, dynamic>
Load user preferences
promptForPreferences() Future<Map<String, dynamic>>
Ask user if they want to use saved preferences or change them
savePreferences(Map<String, dynamic> prefs) → void
Save user preferences