StringExtensions extension

on

Methods

isValidKey() bool

Available on String, provided by the StringExtensions extension

Checks if the string would make a valid key
makeKeyUnique(Set<String> existingKeys) String

Available on String, provided by the StringExtensions extension

Makes the key unique by adding a suffix if needed
toValidKey({String format = 'camelCase'}) String

Available on String, provided by the StringExtensions extension

Converts a string to a valid Dart method name / ARB key