ASTStringExtractor class
Constructors
-
ASTStringExtractor({List<
String> ? whitelist})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
widgetWhitelist
→ List<
String> -
Widget whitelist (types we consider when searching for strings)
final
Methods
-
extractStrings(
String source) → List< ExtractedString> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited