ArbLoader class
Utility class to load ARB files and extract existing keys
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
findArbFiles(
String directory) → List< String> - Find all ARB files in a directory
-
findKeyForString(
String stringValue, Map< String, String> arbKeys) → String? - Find the ARB key for a given string value
-
loadArbKeys(
String arbFilePath) → Map< String, String> - Load ARB file and return map of key -> value
-
loadMultipleArbFiles(
List< String> arbFilePaths) → Map<String, String> - Load multiple ARB files and merge their keys